@@ -2,8 +2,7 @@
 
    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
-#ifndef MESSAGELIST_UTILS_THEMECONFIGBUTTON_H
-#define MESSAGELIST_UTILS_THEMECONFIGBUTTON_H
+#pragma once
 
 #include <QPushButton>
 #include <messagelist_export.h>
@@ -39,9 +38,8 @@ Q_SIGNALS:
     void configureDialogCompleted();
 
 private:
-    ThemeConfigButtonPrivate *const d;
+    std::unique_ptr<ThemeConfigButtonPrivate> const d;
 };
 } // namespace Utils
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_UTILS_THEMECONFIGBUTTON_H
