@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,10 +7,10 @@
 #include "dkimmanagerkeydialogtest.h"
 #include "dkim-verify/dkimmanagerkeydialog.h"
 #include "dkim-verify/dkimmanagerkeywidget.h"
-#include <QVBoxLayout>
 #include <QDialogButtonBox>
-#include <QTest>
 #include <QStandardPaths>
+#include <QTest>
+#include <QVBoxLayout>
 
 QTEST_MAIN(DKIMManagerKeyDialogTest)
 
@@ -28,13 +28,13 @@ void DKIMManagerKeyDialogTest::shouldHaveDefaultValue()
 {
     MessageViewer::DKIMManagerKeyDialog dlg;
 
-    auto *mainLayout = dlg.findChild<QVBoxLayout *>(QStringLiteral("mainlayout"));
+    auto mainLayout = dlg.findChild<QVBoxLayout *>(QStringLiteral("mainlayout"));
     QVERIFY(mainLayout);
 
-    auto *w = dlg.findChild<MessageViewer::DKIMManagerKeyWidget *>(QStringLiteral("managerWidget"));
+    auto w = dlg.findChild<MessageViewer::DKIMManagerKeyWidget *>(QStringLiteral("managerWidget"));
     QVERIFY(w);
 
-    auto *buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
+    auto buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
     QVERIFY(buttonBox);
     QCOMPARE(buttonBox->standardButtons(), {QDialogButtonBox::Close});
 }
