@@ -9,7 +9,7 @@
 #include "header/grantleeheaderformatter.h"
 #include "header/headerstrategy.h"
 
-#include <kmime/kmime_message.h>
+#include <KMime/KMimeMessage>
 
 using namespace MessageViewer;
 
@@ -38,10 +38,7 @@ GrantleeHeaderTestStyle::GrantleeHeaderTestStyle()
 {
 }
 
-GrantleeHeaderTestStyle::~GrantleeHeaderTestStyle()
-{
-    delete d;
-}
+GrantleeHeaderTestStyle::~GrantleeHeaderTestStyle() = default;
 
 const char *GrantleeHeaderTestStyle::name() const
 {
