@@ -8,10 +8,8 @@
 #include "headerstyleplugin.h"
 #include "messageviewer_debug.h"
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <KPluginMetaData>
 #include <QFileInfo>
-#include <QSet>
 
 using namespace MessageViewer;
 
@@ -25,6 +23,7 @@ public:
     PimCommon::PluginUtilData pluginData;
     QString metaDataFileNameBaseName;
     QString metaDataFileName;
+    KPluginMetaData data;
     MessageViewer::HeaderStylePlugin *plugin = nullptr;
     bool isEnabled = false;
 };
@@ -76,7 +75,7 @@ QString HeaderStylePluginManagerPrivate::configPrefixSettingKey() const
 
 void HeaderStylePluginManagerPrivate::initializePluginList()
 {
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("messageviewer/headerstyle"));
+    const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("messageviewer/headerstyle"));
 
     QVectorIterator<KPluginMetaData> i(plugins);
     i.toBack();
@@ -95,6 +94,7 @@ void HeaderStylePluginManagerPrivate::initializePluginList()
         info.isEnabled = isPluginActivated;
         info.metaDataFileNameBaseName = QFileInfo(data.fileName()).baseName();
         info.metaDataFileName = data.fileName();
+        info.data = data;
         const QString version = data.version();
         if (pluginVersion() == version) {
             const QVariant p = data.rawData().value(QStringLiteral("X-KDE-MessageViewer-Header-Order")).toVariant();
@@ -137,9 +137,8 @@ QVector<MessageViewer::HeaderStylePlugin *> HeaderStylePluginManagerPrivate::plu
 
 void HeaderStylePluginManagerPrivate::loadPlugin(HeaderStylePluginInfo *item)
 {
-    KPluginLoader pluginLoader(item->metaDataFileName);
-    if (pluginLoader.factory()) {
-        item->plugin = pluginLoader.factory()->create<MessageViewer::HeaderStylePlugin>(q, QVariantList() << item->metaDataFileNameBaseName);
+    if (auto plugin = KPluginFactory::instantiatePlugin<MessageViewer::HeaderStylePlugin>(item->data, q, QVariantList() << item->metaDataFileName).plugin) {
+        item->plugin = plugin;
         item->plugin->setIsEnabled(item->isEnabled);
         item->pluginData.mHasConfigureDialog = false;
         mPluginDataList.append(item->pluginData);
@@ -170,10 +169,7 @@ HeaderStylePluginManager::HeaderStylePluginManager(QObject *parent)
     d->initializePluginList();
 }
 
-HeaderStylePluginManager::~HeaderStylePluginManager()
-{
-    delete d;
-}
+HeaderStylePluginManager::~HeaderStylePluginManager() = default;
 
 QVector<MessageViewer::HeaderStylePlugin *> HeaderStylePluginManager::pluginsList() const
 {
@@ -184,7 +180,8 @@ QStringList HeaderStylePluginManager::pluginListName() const
 {
     QStringList lst;
     lst.reserve(d->pluginsList().count());
-    for (MessageViewer::HeaderStylePlugin *plugin : d->pluginsList()) {
+    const auto pluginsList{d->pluginsList()};
+    for (MessageViewer::HeaderStylePlugin *plugin : pluginsList) {
         lst << plugin->name();
     }
     return lst;
