@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef URLHASHING_H
-#define URLHASHING_H
+#pragma once
 
 #include "webengineviewer_private_export.h"
 #include <QString>
@@ -20,16 +19,15 @@ public:
     explicit UrlHashing(const QUrl &url);
     ~UrlHashing();
 
-    static QString canonicalizeUrl(QUrl url);
-    static QStringList generatePathsToCheck(const QString &str, const QString &query);
-    static QStringList generateHostsToCheck(const QString &str);
+    static Q_REQUIRED_RESULT QString canonicalizeUrl(QUrl url);
+    static Q_REQUIRED_RESULT QStringList generatePathsToCheck(const QString &str, const QString &query);
+    static Q_REQUIRED_RESULT QStringList generateHostsToCheck(const QString &str);
 
     /*long hash, short hash*/
-    QHash<QByteArray, QByteArray> hashList() const;
+    Q_REQUIRED_RESULT QHash<QByteArray, QByteArray> hashList() const;
 
 private:
     const QUrl mUrl;
 };
 }
 
-#endif // URLHASHING_H
